@@ -1,6 +1,6 @@
 package File::ChangeNotify::Watcher::KQueue;
-BEGIN {
-  $File::ChangeNotify::Watcher::KQueue::VERSION = '0.19';
+{
+  $File::ChangeNotify::Watcher::KQueue::VERSION = '0.21';
 }
 
 use strict;
@@ -14,13 +14,13 @@ use IO::KQueue;
 
 extends 'File::ChangeNotify::Watcher';
 
-has 'absorb_delay' => (
+has absorb_delay => (
     is      => 'ro',
     isa     => 'Int',
     default => 100,
 );
 
-has '_kqueue' => (
+has _kqueue => (
     is       => 'ro',
     isa      => 'IO::KQueue',
     default  => sub { IO::KQueue->new },
@@ -30,7 +30,7 @@ has '_kqueue' => (
 # We need to keep hold of filehandles for all the directories *and* files in the
 # tree. KQueue events will be automatically deleted when the filehandles go out
 # of scope.
-has '_files' => (
+has _files => (
     is       => 'ro',
     isa      => 'HashRef',
     default  => sub { {} },
@@ -70,8 +70,9 @@ sub _get_events {
 
     my @events;
     foreach my $kevent (@kevents) {
-
         my $path  = $kevent->[KQ_UDATA];
+        next if $self->_path_is_excluded($path);
+
         my $flags = $kevent->[KQ_FFLAGS];
 
         # Delete - this works reasonably well with KQueue
@@ -184,7 +185,7 @@ sub _watch_file {
 
     # Don't panic if we can't open a file
     open my $fh, '<', $file or warn "Can't open '$file': $!";
-    return unless $fh;
+    return unless $fh && defined fileno $fh;
 
     # Store this filehandle (this will automatically nuke any existing events
     # assigned to the file)
@@ -230,6 +231,10 @@ necessary. The important keys are: C<kern.maxfiles> and
 C<kern.maxfilesperproc>.  You can see how many files your system current has
 open with C<kern.openfiles>.
 
+On OpenBSD, the C<sysctl> keys are C<kern.maxfiles> and C<kern.nfiles>.
+Per-process limits are set in F</etc/login.conf>. See L<login.conf(5)> for
+details.
+
 =head1 SUPPORT
 
 I (Dave Rolsky) cannot test this class, as I have no BSD systems. Reasonable
